@@ -33,6 +33,11 @@
         <source>Share</source>
         <translation type="unfinished">Compartir</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Compress</source>
+        <translation type="unfinished">Comprimir</translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Documents</source>
@@ -58,6 +63,16 @@
         <source>Videos</source>
         <translation type="unfinished">Videos</translation>
     </message>
+    <message>
+        <location filename="../error.cpp" line="10"/>
+        <source>Not enough space to proceed.</source>
+        <translation type="unfinished">No hay suficiente espacio para proceder.</translation>
+    </message>
+    <message>
+        <location filename="../error.cpp" line="10"/>
+        <source>You don't have permissions to proceed.</source>
+        <translation type="unfinished">No tiene permisos para proceder.</translation>
+    </message>
 </context>
 <context>
     <name>BookWindow</name>
@@ -74,6 +89,11 @@
         <source>Home folder</source>
         <translation type="unfinished">Carpeta de inicio</translation>
     </message>
+    <message>
+        <location filename="../home.cpp" line="10"/>
+        <source>Compress destination</source>
+        <translation type="unfinished">Destino de compresión</translation>
+    </message>
 </context>
 <context>
     <name>ClipWindow</name>
@@ -113,6 +133,11 @@
         <source>Create new folder</source>
         <translation type="unfinished">Crear nueva carpeta</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Create new document</source>
+        <translation type="unfinished">Crear nuevo documento</translation>
+    </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Sort</source>
@@ -159,6 +184,11 @@
         <source>Source doesn&apos;t exist.</source>
         <translation type="unfinished">No existe el archivo fuente.</translation>
     </message>
+    <message>
+        <location filename="../qtcopydialog.cpp" line="10"/>
+        <source>No enough space for copy the file.</source>
+        <translation type="unfinished">No hay espacio para copiar el archivo.</translation>
+    </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source file is a directory. Omitting source directory.</source>
@@ -383,6 +413,11 @@
         <source>Delete items from clipboard on Paste</source>
         <translation type="unfinished">Borrar ítems del Portapapeles al Pegar</translation>
     </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Enable multiselection</source>
+        <translation type="unfinished">Habilitar multiselección</translation>
+    </message>
 </context>
 <context>
     <name>NewFolder</name>
@@ -480,6 +515,11 @@
         <source>Are you sure you want to delete %1?</source>
         <translation type="unfinished">Está seguro que desea borrar %1?</translation>
     </message>
+    <message>
+        <location filename="../askdialog.cpp" line="10"/>
+        <source>Are you sure you want to delete selected files?</source>
+        <translation type="unfinished">Está seguro que desea borrar los archivos seleccionados?</translation>
+    </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Yes</source>
@@ -529,5 +569,131 @@
         <translation type="unfinished">Tamaño (grandes primero)</translation>
     </message>
 </context>
-
+<context>
+    <name>NewDoc</name>
+    <message>
+        <location filename="../newdoc.cpp" line="10"/>
+        <source>New document</source>
+        <translation type="unfinished">Documento nuevo</translation>
+    </message>
+    <message>
+        <location filename="../newdoc.cpp" line="10"/>
+        <source>Create</source>
+        <translation type="unfinished">Crear</translation>
+    </message>
+    <message>
+        <location filename="../newdoc.cpp" line="10"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
+    <message>
+        <location filename="../newdoc.cpp" line="10"/>
+        <source>Enter name for new document</source>
+        <translation type="unfinished">Ingrese nombre para el documento</translation>
+    </message>
+    <message>
+        <location filename="../newdoc.cpp" line="10"/>
+        <source>Enter a valid file name</source>
+        <translation type="unfinished">Ingrese un nombre válido</translation>
+    </message>
+    <message>
+        <location filename="../newdoc.cpp" line="10"/>
+        <source>The file already exists. Try another name</source>
+        <translation type="unfinished">El archivo ya existe. Intente otro nombre</translation>
+    </message>
+    <message>
+        <location filename="../newdoc.cpp" line="10"/>
+        <source>Cannot create the file. Check permissions</source>
+        <translation type="unfinished">No se puede crear el documento. Chequee permisos</translation>
+    </message>
+</context>
+<context>
+    <name>Error</name>
+    <message>
+        <location filename="../error.cpp" line="10"/>
+        <source>Error</source>
+        <translation type="unfinished">Error</translation>
+    </message>
+    <message>
+        <location filename="../error.cpp" line="10"/>
+        <source>Accept</source>
+        <translation type="unfinished">Aceptar</translation>
+    </message>
+</context>
+<context>
+    <name>CompressDlg</name>
+    <message>
+        <location filename="../compressdlg.cpp" line="10"/>
+        <source>Compress</source>
+        <translation type="unfinished">Comprimir</translation>
+    </message>
+    <message>
+        <location filename="../compressdlg.cpp" line="10"/>
+        <source>File name</source>
+        <translation type="unfinished">Nombre del archivo</translation>
+    </message>
+    <message>
+        <location filename="../compressdlg.cpp" line="10"/>
+        <source>Compression method</source>
+        <translation type="unfinished">Método de compresión</translation>
+    </message>
+    <message>
+        <location filename="../compressdlg.cpp" line="10"/>
+        <source>Destination folder</source>
+        <translation type="unfinished">Carpeta destino</translation>
+    </message>
+    <message>
+        <location filename="../compressdlg.cpp" line="10"/>
+        <source>Accept</source>
+        <translation type="unfinished">Aceptar</translation>
+    </message>
+    <message>
+        <location filename="../compressdlg.cpp" line="10"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
+    <message>
+        <location filename="../compressdlg.cpp" line="10"/>
+        <source>The file already exists. Try another name.</source>
+        <translation type="unfinished">El archivo ya existe. Pruebe otro nombre.</translation>
+    </message>
+    <message>
+        <location filename="../compressdlg.cpp" line="10"/>
+        <source>Not enough space to proceed.</source>
+        <translation type="unfinished">No hay suficiente espacio para proceder.</translation>
+    </message>
+    <message>
+        <location filename="../compressdlg.cpp" line="10"/>
+        <source>You don't have permissions to proceed.</source>
+        <translation type="unfinished">No tiene permisos para proceder.</translation>
+    </message>
+</context>
+<context>
+    <name>Compress</name>
+    <message>
+        <location filename="../compress.cpp" line="10"/>
+        <source>Compressing</source>
+        <translation type="unfinished">Comprimiendo</translation>
+    </message>
+    <message>
+        <location filename="../compress.cpp" line="10"/>
+        <source>Adding %1...</source>
+        <translation type="unfinished">Añadiendo %1...</translation>
+    </message>
+    <message>
+        <location filename="../compress.cpp" line="10"/>
+        <source>Operation finished.</source>
+        <translation type="unfinished">Operación terminada.</translation>
+    </message>
+    <message>
+        <location filename="../compress.cpp" line="10"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
+    <message>
+        <location filename="../compress.cpp" line="10"/>
+        <source>Close</source>
+        <translation type="unfinished">Cerrar</translation>
+    </message>
+</context>
 </TS>
